/*
 * CoverFinder - Find and download cover images from Amazon
 * Copyright (C) 2007 - 2008 - Sven Salzwedel
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "cf-provider.h"
#include "cf-search-result.h"
#include "cf-marshaller.h"

enum
{
	NOTIFY_PROGRESS, NOTIFY_RESULT, SIGNAL_NUM
};

static guint signals[SIGNAL_NUM];

static void cf_provider_base_init (gpointer g_class)
{
	static gboolean initialized = FALSE;

	if (!initialized) {
		signals[NOTIFY_PROGRESS] = g_signal_new ("notify-progress",
			CF_TYPE_PROVIDER, G_SIGNAL_RUN_FIRST, 0, NULL, NULL,
			g_cclosure_user_marshal_VOID__DOUBLE_STRING, G_TYPE_NONE, 2,
			G_TYPE_DOUBLE, G_TYPE_STRING);

		signals[NOTIFY_RESULT] = g_signal_new ("notify-result",
			CF_TYPE_PROVIDER, G_SIGNAL_RUN_FIRST, 0, NULL, NULL,
			g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, G_TYPE_OBJECT);

		initialized = TRUE;
	}
}

GType cf_provider_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
		static const GTypeInfo info = { sizeof(CfProviderInterface),
			cf_provider_base_init, NULL, NULL, NULL, NULL, 0, 0, NULL };
		type
			= g_type_register_static (G_TYPE_INTERFACE, "CfProvider", &info, 0);
	}
	return type;
}

gchar *cf_provider_get_name (CfProvider *self)
{
	return CF_PROVIDER_GET_INTERFACE (self)->get_name (self);
}

void cf_provider_perform_search (CfProvider *self, gint flavor_id,
	CfSearch *search)
{
	CF_PROVIDER_GET_INTERFACE (self)->perform_search (self, flavor_id, search);
}

GSList *cf_provider_get_results (CfProvider *self)
{
	return CF_PROVIDER_GET_INTERFACE (self)->get_results (self);
}

void cf_provider_free_results (CfProvider *self)
{
	CF_PROVIDER_GET_INTERFACE (self)->free_results (self);
}

void cf_provider_notify_progress (CfProvider *self, gdouble fraction,
	gchar *message)
{
	g_signal_emit (self, signals[NOTIFY_PROGRESS], 0, fraction, message);
}

void cf_provider_notify_result (CfProvider *self, CfSearchResult *result)
{
	g_signal_emit (self, signals[NOTIFY_RESULT], 0, result);
}
