/*
 * CoverFinder - Find and download cover images from Amazon
 * Copyright (C) 2007 - 2008 - Sven Salzwedel
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#ifndef _CF_PROVIDER
#define _CF_PROVIDER

#include <glib-object.h>
#include "cf-search.h"
#include "cf-search-result.h"

G_BEGIN_DECLS

#define CF_TYPE_PROVIDER cf_provider_get_type()

#define CF_PROVIDER(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), CF_TYPE_PROVIDER, CfProvider))

#define CF_IS_PROVIDER(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CF_TYPE_PROVIDER))

#define CF_PROVIDER_GET_INTERFACE(obj) \
  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), CF_TYPE_PROVIDER, CfProviderInterface))

typedef struct _CfProvider CfProvider;
typedef struct
{
	GTypeInterface parent;
	gchar * (*get_name) (CfProvider *self);
	void (*perform_search) (CfProvider *self, gint flavor_id, CfSearch *search);
	GSList * (*get_results) (CfProvider *self);
	void (*free_results) (CfProvider *self);
} CfProviderInterface;

GType cf_provider_get_type (void);

gchar *cf_provider_get_name (CfProvider *self);
void cf_provider_perform_search (CfProvider *self, gint flavor_id,
	CfSearch *search);
GSList *cf_provider_get_results (CfProvider *self);
void cf_provider_free_results (CfProvider *self);

void cf_provider_notify_progress (CfProvider *self, gdouble fraction, gchar *message);
void cf_provider_notify_result (CfProvider *self, CfSearchResult *result);

G_END_DECLS

#endif /* _CF_PROVIDER */
