/*
 * CoverFinder - Find and download cover images from Amazon
 * Copyright (C) 2007 - 2008 - Sven Salzwedel
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "config.h"
#include "cf-util.h"

gchar *cf_find_file (const gchar *filename)
{
	const gchar * const *data_dirs;
	const gchar *dir = NULL;
	gchar *test;
	int i = 0;


	/* try data dir, this is useful for testing while developing */
	test = g_build_filename ("../data", filename, NULL);
	if (g_file_test (test, G_FILE_TEST_EXISTS)) {
		return test;
	}
	g_free (test);

	test = g_build_filename ("./data", filename, NULL);
	if (g_file_test (test, G_FILE_TEST_EXISTS)) {
		return test;
	}
	g_free (test);


	/* look in installation dir */
	test = g_build_filename (PACKAGE_DIR, filename, NULL);
	if (g_file_test (test, G_FILE_TEST_EXISTS)) {
		return test;
	}
	g_free (test);

	/* look in system data dirs */
	data_dirs = g_get_system_data_dirs ();
	do {
		dir = data_dirs[i++];
		test = g_build_filename (dir, PACKAGE, filename, NULL);
		if (g_file_test (test, G_FILE_TEST_EXISTS)) {
			return test;
		}
		g_free (test);
	} while (dir != NULL);

	return NULL;
}

gchar *cf_get_cache_dir ()
{
	gchar *cache_dir;

	cache_dir = g_build_filename (g_get_user_cache_dir (), g_get_prgname (),
		NULL);
	return cache_dir;
}
